summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/machine/ay31015.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/machine/ay31015.h')
-rw-r--r--src/devices/machine/ay31015.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/devices/machine/ay31015.h b/src/devices/machine/ay31015.h
index 3330c7b0294..f319f5aea96 100644
--- a/src/devices/machine/ay31015.h
+++ b/src/devices/machine/ay31015.h
@@ -19,6 +19,7 @@
enum ay31015_input_pin_t
{
AY31015_SWE = 16, /* -SWE - Pin 16 - Status word enable */
+ AY31015_RCP = 17, /* RCP - Pin 17 - Receiver clock pulse */
AY31015_RDAV = 18, /* -RDAV - Pin 18 - Reset data available */
AY31015_SI = 20, /* SI - Pin 20 - Serial input */
AY31015_XR = 21, /* XR - Pin 21 - External reset */
@@ -27,7 +28,8 @@ enum ay31015_input_pin_t
AY31015_TSB = 36, /* TSB - Pin 36 - Number of stop bits */
AY31015_NB2 = 37, /* NB2 - Pin 37 - Number of bits #2 */
AY31015_NB1 = 38, /* NB1 - Pin 38 - Number of bits #1 */
- AY31015_EPS = 39 /* EPS - Pin 39 - Odd/Even parity select */
+ AY31015_EPS = 39, /* EPS - Pin 39 - Odd/Even parity select */
+ AY31015_TCP = 40 /* TCP - Pin 40 - Transmitter clock pulse */
};